==> jc-1.4.0.tar.gz: gnu/java/net/protocol/http/ByteArrayRequestBodyWriter.h <==
// public class gnu.java.net.protocol.http.ByteArrayRequestBodyWriter

// class file dependencies
// @dep_class 5694ba267a7ae664 gnu_java_net_protocol_http_ByteArrayRequestBodyWriter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter_H_
#define _JC_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_refs	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_nonrefs	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$refs	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$refs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$nonrefs	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object;

typedef const struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vmethods	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtable	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtype	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object *, struct _jc_byte_array *);

// Virtual methods
extern jint _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$method$getContentLength$b5dadbc29a008b07(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object *);
extern void _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object *);
extern jint _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$method$write$094fff752b1a3482(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object *, struct _jc_byte_array *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$method_info$getContentLength$b5dadbc29a008b07;
extern _jc_method _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$method_info$write$094fff752b1a3482;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vmethods {
	jint	(*getContentLength$b5dadbc29a008b07)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object *);
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object *);
	jint	(*write$094fff752b1a3482)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object *, struct _jc_byte_array *);
};

// Vtable
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vmethods	gnu_java_net_protocol_http_ByteArrayRequestBodyWriter;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_refs {
	_jc_byte_array	*content;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$refs {
    _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_refs	gnu_java_net_protocol_http_ByteArrayRequestBodyWriter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_nonrefs {
	jint	pos;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_nonrefs	gnu_java_net_protocol_http_ByteArrayRequestBodyWriter;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object {
	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtype _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_ByteArrayRequestBodyWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/http/ByteArrayRequestBodyWriter.h <==
// public class gnu.java.net.protocol.http.ByteArrayRequestBodyWriter

// class file dependencies
// @dep_class 5694ba267a7ae664 gnu_java_net_protocol_http_ByteArrayRequestBodyWriter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter_H_
#define _JC_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_refs	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_nonrefs	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$refs	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$refs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$nonrefs	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object;

typedef const struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vmethods	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtable	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtype	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$method$getContentLength$b5dadbc29a008b07(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$method$write$094fff752b1a3482(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$method_info$getContentLength$b5dadbc29a008b07;
extern _jc_method _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$method_info$write$094fff752b1a3482;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vmethods {
	jint	(*getContentLength$b5dadbc29a008b07)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object *) _JC_JCNI_ATTR;
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object *) _JC_JCNI_ATTR;
	jint	(*write$094fff752b1a3482)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vmethods	gnu_java_net_protocol_http_ByteArrayRequestBodyWriter;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_refs {
	_jc_byte_array	*content;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$refs {
    _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_refs	gnu_java_net_protocol_http_ByteArrayRequestBodyWriter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_nonrefs {
	jint	pos;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$sub_nonrefs	gnu_java_net_protocol_http_ByteArrayRequestBodyWriter;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$object {
	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$vtype _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_ByteArrayRequestBodyWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_ByteArrayRequestBodyWriter_H_ */
